@@ -29,7 +29,6 @@
 #' @param ci.lvl A number that specify the confidence level \eqn{\alpha}. Default is 0.05.
 #' @import stats
 #' @import KernSmooth
-#' @import twostageTE
 #' @import utils
 #' @return \code{hr} The estimated hazard ratio
 #' @return \code{tau} The estimated scaled parameter of the limiting Chernoff distribution
@@ -143,7 +142,3 @@ gcm.unique <- function(x, y){
   logcm <- gcmlcm(x.unique, y.unique, type = 'gcm')
   return(logcm)
 }
-
-
-person(c(person(given = "Yujian", family = "Wu", role = c("aut", "cre"), email = "yujianwu@umass.edu", comment = c(ORCID = "0000-0001-9163-6773")),
-         c(person(given = "Ted", family = "Westling", role = c("ths"), email = "twestling@umass.edu", comment = c(ORCID = "0000-0002-3362-1378")))))
